# OWASP Juice Shop for Core WAAP Demo.

We use [OWASP Juice Shop](https://owasp.org/www-project-juice-shop/) as Webapplication to test and demonstrate the capabilities of the USP Core WAAP in Kubernetes.

## Demo / Test Cases

The first Juice Shop challenge is to find the 'hidden' score board. It is located at `/#/score-board`.

## Suitable Core WAAP Demo Cases

### Challenge: **Login Admin**
1. Go to *Login*
2. Enter `' OR TRUE;` as Username
3. Enter some letters in the password field and press Login

You shoud be logged in as `admin@juice-sh.op`

Behaviour with Core WAAè (e.g. WAAP Config below)
```
...
  crs:
    mode: BLOCK
    securityLevel: 5
    paranoiaLevel: 1
...
```
-> The Login attempt above will be blocked due triggering the rule *942100*.

---
### Challenge: **CSRF (Cross-Site Request Forgery)**
Preconditions:
1. In the Core WAAP configuration, disable crs (Coraza) entirely, or it will also prevent this attack.
2. Create Account
3. Login

Attack:
1. Go to *Account* / *account name* (shows "/profile" page)
2. Set the empty "Username" field to any value, e.g. "harry", and save
3. Open the file "csrf-attack-example.html" in your browser in a separate tab
4. In the form in that HTML page, click the submit button. The form will send a POST request to the Juiceshop which
   changes the username; this works because the request will use the existing authenticated session for that.

In the Juiceshop page, reload the profile - the username has now been changed to "hacked".

To prevent this attack, enable this config in the Core WAAP config:

```
  csrfPolicy:
    enabled: true
```

---
### Challenge: **Reflected XSS**
Preconditions: 
1. Create Account
2. Login
3. Order and pay a product (go through the checkout procedure with adding address, credit card etc.)

Attack:
1. Go to *Account* / *Orders & Payments* / *Order History*
2. Click the the truck to show the details
3. modify the URL `/#/track-result?id=<iframe src%3D"javascript:alert(`xss`)">`
4. Reload the page by pressing F5

Depending on the enabled Rules security and paranoia level the requests is blocked by rule from the set `REQUEST-941-APPLICATION-ATTACK-XSS`

---
### Challenge: **Error Handling**
Requesting an URL like `/rest/foo` will lead to an server-side error which reveals some information about the application unintentionally.
The Core WAAP with the *Response Rule enabled* and *paranoiaLevel >=2* will block the repsonse.

---
### False Positive in Login Form
Example of triggering a false positive:
1. Go to *Login*
2. Enter some username (has not be be a valid for demo pusposed)
3. use a pattern like `<script>`in the password form field

Depending on the configured *ParanioLevel* and activated rules, this will trigger some CRS alerts.
This way, the need of configuring *requestRuleExceptions* can be demostrated. Furthermore it can be shown, how our auto-learn tool eases the process to get rid of false positives.


